@@ -34,6 +34,8 @@ VLOG_DEFINE_THIS_MODULE(encaps);
  */
 #define	OVN_MVTEP_CHASSISID_DELIM '@'
 
+static char *current_br_int_name = NULL;
+
 void
 encaps_register_ovs_idl(struct ovsdb_idl *ovs_idl)
 {
@@ -356,6 +358,20 @@ chassis_tzones_overlap(const struct sset *transport_zones,
     return false;
 }
 
+static void
+clear_old_tunnels(const struct ovsrec_bridge *old_br_int)
+{
+    for (size_t i = 0; i < old_br_int->n_ports; i++) {
+        const struct ovsrec_port *port = old_br_int->ports[i];
+        const char *id = smap_get(&port->external_ids, "ovn-chassis-id");
+        if (id) {
+            VLOG_DBG("Clearing old tunnel port \"%s\" (%s) from bridge "
+                     "\"%s\".", port->name, id, old_br_int->name);
+            ovsrec_bridge_update_ports_delvalue(old_br_int, port);
+        }
+    }
+}
+
 void
 encaps_run(struct ovsdb_idl_txn *ovs_idl_txn,
            const struct ovsrec_bridge_table *bridge_table,
@@ -370,6 +386,30 @@ encaps_run(struct ovsdb_idl_txn *ovs_idl_txn,
         return;
     }
 
+    if (!current_br_int_name) {
+        /* The controller has just started, we need to look through all
+         * bridges for old tunnel ports. */
+       const struct ovsrec_bridge *br;
+        OVSREC_BRIDGE_TABLE_FOR_EACH (br, bridge_table) {
+            if (!strcmp(br->name, br_int->name)) {
+                continue;
+            }
+            clear_old_tunnels(br);
+        }
+        current_br_int_name = xstrdup(br_int->name);
+    } else if (strcmp(current_br_int_name, br_int->name)) {
+        /* The integration bridge was changed, clear tunnel ports from
+         * the old one. */
+        const struct ovsrec_bridge *old_br_int =
+            get_bridge(bridge_table, current_br_int_name);
+        if (old_br_int) {
+            clear_old_tunnels(old_br_int);
+        }
+
+        free(current_br_int_name);
+        current_br_int_name = xstrdup(br_int->name);
+    }
+
     const struct sbrec_chassis *chassis_rec;
     const struct ovsrec_bridge *br;
 
@@ -484,3 +524,9 @@ encaps_cleanup(struct ovsdb_idl_txn *ovs_idl_txn,
 
     return !any_changes;
 }
+
+void
+encaps_destroy(void)
+{
+    free(current_br_int_name);
+}
