@@ -421,6 +421,12 @@ populate_remote_chassis_macs(const struct sbrec_chassis *my_chassis,
             char *save_ptr2 = NULL;
             char *chassis_mac_bridge = strtok_r(token, ":", &save_ptr2);
             char *chassis_mac_str = strtok_r(NULL, "", &save_ptr2);
+            if (!chassis_mac_str) {
+                VLOG_WARN("Parsing of ovn-chassis-mac-mappings failed for: "
+                          "\"%s\", the correct format is \"br-name1:MAC1\".",
+                          token);
+                continue;
+            }
             struct remote_chassis_mac *remote_chassis_mac = NULL;
             remote_chassis_mac = xmalloc(sizeof *remote_chassis_mac);
             hmap_insert(&remote_chassis_macs, &remote_chassis_mac->hmap_node,
@@ -698,6 +704,14 @@ put_replace_router_port_mac_flows(struct ovsdb_idl_index
 
         ofpact_put_OUTPUT(ofpacts_p)->port = ofport;
 
+        /* Replace the MAC back and strip vlan. In case of l2 flooding
+         * traffic (ARP/ND) we need to restore previous state so other ports
+         * do not receive the traffic tagged and with wrong MAC. */
+        ofpact_put_SET_ETH_SRC(ofpacts_p)->mac = router_port_mac;
+        if (tag) {
+            ofpact_put_STRIP_VLAN(ofpacts_p);
+        }
+
         ofctrl_add_flow(flow_table, OFTABLE_LOG_TO_PHY, 150,
                         localnet_port->header_.uuid.parts[0],
                         &match, ofpacts_p, &localnet_port->header_.uuid);
@@ -1309,6 +1323,24 @@ consider_port_binding(struct ovsdb_idl_index *sbrec_port_binding_by_name,
             }
         }
 
+        /* Table 37, priority 150.
+         * =======================
+         *
+         * Handles packets received from ports of type "localport".  These
+         * ports are present on every hypervisor.  Traffic that originates at
+         * one should never go over a tunnel to a remote hypervisor,
+         * so resubmit them to table 38 for local delivery. */
+        if (!strcmp(binding->type, "localport")) {
+            ofpbuf_clear(ofpacts_p);
+            put_resubmit(OFTABLE_LOCAL_OUTPUT, ofpacts_p);
+            match_init_catchall(&match);
+            match_set_reg(&match, MFF_LOG_INPORT - MFF_REG0,
+                          binding->tunnel_key);
+            match_set_metadata(&match, htonll(binding->datapath->tunnel_key));
+            ofctrl_add_flow(flow_table, OFTABLE_REMOTE_OUTPUT, 150,
+                            binding->header_.uuid.parts[0], &match,
+                            ofpacts_p, &binding->header_.uuid);
+        }
     } else if (!tun && !is_ha_remote) {
         /* Remote port connected by localnet port */
         /* Table 38, priority 100.
@@ -1840,32 +1872,6 @@ physical_run(struct physical_ctx *p_ctx,
     ofctrl_add_flow(flow_table, OFTABLE_REMOTE_OUTPUT, 150, 0,
                     &match, &ofpacts, hc_uuid);
 
-    /* Table 37, priority 150.
-     * =======================
-     *
-     * Handles packets received from ports of type "localport".  These ports
-     * are present on every hypervisor.  Traffic that originates at one should
-     * never go over a tunnel to a remote hypervisor, so resubmit them to table
-     * 38 for local delivery. */
-    match_init_catchall(&match);
-    ofpbuf_clear(&ofpacts);
-    put_resubmit(OFTABLE_LOCAL_OUTPUT, &ofpacts);
-    const char *localport;
-    SSET_FOR_EACH (localport, p_ctx->local_lports) {
-        /* Iterate over all local logical ports and insert a drop
-         * rule with higher priority for every localport in this
-         * datapath. */
-        const struct sbrec_port_binding *pb = lport_lookup_by_name(
-            p_ctx->sbrec_port_binding_by_name, localport);
-        if (pb && !strcmp(pb->type, "localport")) {
-            match_set_reg(&match, MFF_LOG_INPORT - MFF_REG0, pb->tunnel_key);
-            match_set_metadata(&match, htonll(pb->datapath->tunnel_key));
-            ofctrl_add_flow(flow_table, OFTABLE_REMOTE_OUTPUT, 150,
-                            pb->header_.uuid.parts[0],
-                            &match, &ofpacts, hc_uuid);
-        }
-    }
-
     /* Table 37, Priority 0.
      * =======================
      *
