@@ -115,6 +115,10 @@ static const char *rbac_igmp_group_auth[] =
     {""};
 static const char *rbac_igmp_group_update[] =
     {"address", "chassis", "datapath", "ports"};
+static const char *rbac_bfd_auth[] =
+    {""};
+static const char *rbac_bfd_update[] =
+    {"status"};
 
 static struct rbac_perm_cfg {
     const char *table;
@@ -197,6 +201,14 @@ static struct rbac_perm_cfg {
         .update = rbac_igmp_group_update,
         .n_update = ARRAY_SIZE(rbac_igmp_group_update),
         .row = NULL
+    },{
+        .table = "BFD",
+        .auth = rbac_bfd_auth,
+        .n_auth = ARRAY_SIZE(rbac_bfd_auth),
+        .insdel = false,
+        .update = rbac_bfd_update,
+        .n_update = ARRAY_SIZE(rbac_bfd_update),
+        .row = NULL
     },{
         .table = NULL,
         .auth = NULL,
@@ -246,6 +258,7 @@ static struct gen_opts_map supported_dhcp_opts[] = {
     DHCP_OPT_BROADCAST_ADDRESS,
     DHCP_OPT_NETBIOS_NAME_SERVER,
     DHCP_OPT_NETBIOS_NODE_TYPE,
+    DHCP_OPT_NEXT_SERVER,
 };
 
 static struct gen_opts_map supported_dhcpv6_opts[] = {
@@ -723,10 +736,18 @@ main(int argc, char *argv[])
     unixctl_command_register("nb-connection-status", "", 0, 0,
                              ovn_conn_show, ovnnb_idl_loop.idl);
 
-    /* We want to detect all changes to the ovn-sb db. */
+    /* We want to detect all changes to the ovn-sb db so enable change
+     * tracking but, for performance reasons, and because northd
+     * reconciles all database changes, also configure the IDL to only
+     * write columns that actually change value.
+     */
     struct ovsdb_idl_loop ovnsb_idl_loop = OVSDB_IDL_LOOP_INITIALIZER(
         ovsdb_idl_create(ovnsb_db, &sbrec_idl_class, true, true));
     ovsdb_idl_track_add_all(ovnsb_idl_loop.idl);
+    ovsdb_idl_set_write_changed_only_all(ovnsb_idl_loop.idl, true);
+
+    /* Disable alerting for pure write-only columns. */
+    ovsdb_idl_omit_alert(ovnsb_idl_loop.idl, &sbrec_sb_global_col_nb_cfg);
 
     unixctl_command_register("sb-connection-status", "", 0, 0,
                              ovn_conn_show, ovnsb_idl_loop.idl);
