@@ -196,6 +196,7 @@ create_gen_opts(struct hmap *dhcp_opts, struct hmap *dhcpv6_opts,
     dhcp_opt_add(dhcp_opts, "broadcast_address", 28, "ipv4");
     dhcp_opt_add(dhcp_opts, "netbios_name_server", 44, "ipv4");
     dhcp_opt_add(dhcp_opts, "netbios_node_type", 46, "uint8");
+    dhcp_opt_add(dhcp_opts, "next_server", 253, "ipv4");
 
     /* DHCPv6 options. */
     hmap_init(dhcpv6_opts);
@@ -1351,6 +1352,7 @@ test_parse_actions(struct ovs_cmdl_context *ctx OVS_UNUSED)
                 .ct_snat_vip_ptable = OFTABLE_CT_SNAT_HAIRPIN,
                 .fdb_ptable = OFTABLE_GET_FDB,
                 .fdb_lookup_ptable = OFTABLE_LOOKUP_FDB,
+                .common_nat_ct_zone = MFF_LOG_DNAT_ZONE,
             };
             struct ofpbuf ofpacts;
             ofpbuf_init(&ofpacts, 0);
